@@ -62,6 +62,7 @@ class CScoresheet : public QObject
 	int minSectSize;
 	bool hideKeys;
 	QString defaultName;
+	QString defaultDirectory;
 	
 	int lastcellCol;
 	int lastcellRow;
@@ -79,7 +80,6 @@ class CScoresheet : public QObject
 	QDialog *win_setup;
 	QDialog *dlg_about;
 	QDialog *dlg_confirmation;
-	QFileDialog *dlg_file;
 	
 	QSpinBox *stp_players;
 	QSpinBox *stp_rows;
